@@ -24,9 +24,6 @@
 #include <gsf/gsf-output-impl.h>
 #include <gsf/gsf-impl-utils.h>
 
-#include <libgnomevfs/gnome-vfs.h>
-/* libgnomevfs/gnome-vfs-result.h */
-
 struct _GsfOutputGnomeVFS {
     GsfOutput output;
 
@@ -70,6 +67,39 @@ gsf_output_gnomevfs_new (char const *filename, GError **err)
 	return GSF_OUTPUT (output);
 }
 
+/**
+ * gsf_output_gnomevfs_new_uri :
+ * @uri      : resource indicator
+ * @err	     : optionally NULL.
+ *
+ * Returns a new file or NULL.
+ **/
+GsfOutput *
+gsf_output_gnomevfs_new_uri (GnomeVFSURI * uri, GError **err)
+{
+	GsfOutputGnomeVFS *output;
+	GnomeVFSHandle *handle;
+	GnomeVFSResult res;
+
+	if (uri == NULL) {
+		g_set_error (err, gsf_output_error_id (), 0,
+			     "Filename/URI cannot be NULL");
+		return NULL;
+	} else
+		res = gnome_vfs_open_uri (&handle, uri, GNOME_VFS_OPEN_WRITE);
+
+	if (res != GNOME_VFS_OK) {
+		g_set_error (err, gsf_output_error_id (), (gint) res,
+			     gnome_vfs_result_to_string (res));
+		return NULL;
+	}
+
+	output = g_object_new (GSF_OUTPUT_GNOMEVFS_TYPE, NULL);
+	output->handle = handle;
+
+	return GSF_OUTPUT (output);
+}
+
 static gboolean
 gsf_output_gnomevfs_close (GsfOutput *output)
 {
@@ -130,17 +160,19 @@ gsf_output_gnomevfs_write (GsfOutput *output,
 			   guint8 const *buffer)
 {
     GsfOutputGnomeVFS *vfs = GSF_OUTPUT_GNOMEVFS (output);
-    GnomeVFSFileSize nwritten;
-    GnomeVFSResult res;
+    GnomeVFSFileSize nwritten = 0, total_written = 0;
+    GnomeVFSResult res = GNOME_VFS_OK;
 
     g_return_val_if_fail (vfs != NULL, FALSE);
     g_return_val_if_fail (vfs->handle != NULL, FALSE);
 
-    res = gnome_vfs_write (vfs->handle, (gconstpointer)buffer,
-			   (GnomeVFSFileSize) num_bytes, &nwritten);
-    if (GNOME_VFS_OK != res)
-        return FALSE;
-    return nwritten == num_bytes;
+    while ((res == GNOME_VFS_OK) && (total_written < num_bytes))
+	    {
+		    res = gnome_vfs_write (vfs->handle, (gconstpointer)(buffer + total_written),
+					   (GnomeVFSFileSize)(num_bytes - total_written), &nwritten);
+		    total_written += nwritten;
+	    }
+    return (res == GNOME_VFS_OK && total_written == num_bytes);
 }
 
 static void
