@@ -24,6 +24,7 @@
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-input-impl.h>
 #include <gsf/gsf-impl-utils.h>
+#include <gsf/gsf-utils.h>
 #include <gsf/gsf-shared-memory.h>
 
 struct _GsfInputMemory {
@@ -150,35 +151,47 @@ gsf_input_mmap_new (char const *filename, GError **err)
 
 	fd = open (filename, O_RDONLY);
 	if (fd < 0 || fstat (fd, &st) < 0) {
-		if (err != NULL)
+		if (err != NULL) {
+			char *utf8name = gsf_filename_to_utf8 (filename, FALSE);
 			*err = g_error_new (gsf_input_error (), 0,
-				"%s: %s", filename, g_strerror (errno));
+				"%s: %s", utf8name, g_strerror (errno));
+			g_free (utf8name);
+		}
 		if (fd >= 0) close (fd);
 		return NULL;
 	}
 
 	if (!S_ISREG (st.st_mode)) {
-		if (err != NULL)
+		if (err != NULL) {
+			char *utf8name = gsf_filename_to_utf8 (filename, FALSE);
 			*err = g_error_new (gsf_input_error (), 0,
-				"%s: Is not a regular file", filename);
+				"%s: Is not a regular file", utf8name);
+			g_free (utf8name);
+		}
 		close (fd);
 		return NULL;
 	}
 	
 	size = (size_t) st.st_size;
 	if ((off_t) size != st.st_size) { /* Check for overflow */
-		if (err != NULL)
+		if (err != NULL) {
+			char *utf8name = gsf_filename_to_utf8 (filename, FALSE);
 			*err = g_error_new (gsf_input_error (), 0,
-				"%s: %s",filename,
+				"%s: %s", utf8name,
 				"File too large to be memory mapped");
+			g_free (utf8name);
+		}
 		close (fd);
 		return NULL;
 	}
 	buf = mmap (0, size, PROT_READ, MAP_SHARED, fd, (off_t) 0);
 	if (buf == MAP_FAILED) {
-		if (err != NULL)
+		if (err != NULL) {
+			char *utf8name = gsf_filename_to_utf8 (filename, FALSE);
 			*err = g_error_new (gsf_input_error (), 0,
-				"%s: %s", filename, g_strerror (errno));
+				"%s: %s", utf8name, g_strerror (errno));
+			g_free (utf8name);
+		}
 		close (fd);
 		return NULL;
 	}
