@@ -23,6 +23,7 @@
 #include <gsf/gsf-input-stdio.h>
 #include <gsf/gsf-input-impl.h>
 #include <gsf/gsf-impl-utils.h>
+#include <gsf/gsf-utils.h>
 
 #include <stdio.h>
 #include <errno.h>
@@ -57,19 +58,25 @@ gsf_input_stdio_new (char const *filename, GError **err)
 	FILE *file;
 	gsf_off_t size;
 
-	file = fopen (filename, "r");
+	file = fopen (filename, "rb");
 	if (file == NULL || fstat (fileno (file), &st) < 0) {
-		if (err != NULL)
+		if (err != NULL) {
+			char *utf8name = gsf_filename_to_utf8 (filename, FALSE);
 			*err = g_error_new (gsf_input_error (), 0,
-				"%s: %s", filename, g_strerror (errno));
+				"%s: %s", utf8name, g_strerror (errno));
+			g_free (utf8name);
+		}
 		if (file) fclose (file); /* Just in case.  */
 		return NULL;
 	}
 
 	if (!S_ISREG (st.st_mode)) {
-		if (err != NULL)
+		if (err != NULL) {
+			char *utf8name = gsf_filename_to_utf8 (filename, FALSE);
 			*err = g_error_new (gsf_input_error (), 0,
-				"%s: Is not a regular file", filename);
+				"%s: Is not a regular file", utf8name);
+			g_free (utf8name);
+		}
 		fclose (file);
 		return NULL;
 	}
@@ -118,7 +125,7 @@ gsf_input_stdio_read (GsfInput *input, size_t num_bytes,
 		      guint8 *buffer)
 {
 	GsfInputStdio *stdio = GSF_INPUT_STDIO (input);
-	size_t res;
+	size_t nread = 0, total_read = 0;
 
 	g_return_val_if_fail (stdio != NULL, NULL);
 	g_return_val_if_fail (stdio->file != NULL, NULL);
@@ -133,9 +140,14 @@ gsf_input_stdio_read (GsfInput *input, size_t num_bytes,
 		buffer = stdio->buf;
 	}
 
-	res = fread (buffer, 1, num_bytes, stdio->file);
-	if (res < num_bytes)
-		return NULL;
+	while (total_read < num_bytes) {
+		nread = fread (buffer + total_read, 1, 
+			       num_bytes - total_read, stdio->file);
+		total_read += nread;
+		if (total_read < num_bytes &&
+		    (ferror (stdio->file) || feof (stdio->file)))
+			return NULL;
+	}
 
 	return buffer;
 }
@@ -145,6 +157,7 @@ gsf_input_stdio_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 {
 	GsfInputStdio const *stdio = GSF_INPUT_STDIO (input);
 	long loffset;
+	int stdio_whence = SEEK_SET;
 
 	if (stdio->file == NULL)
 		return TRUE;
@@ -155,19 +168,16 @@ gsf_input_stdio_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 		return TRUE;
 	}
 	switch (whence) {
-	case G_SEEK_SET :
-		if (0 == fseek (stdio->file, loffset, SEEK_SET))
-			return FALSE;
+	case G_SEEK_CUR : stdio_whence = SEEK_CUR; break;
+	case G_SEEK_END : stdio_whence = SEEK_END; break;
+	case G_SEEK_SET:
+	default:
 		break;
-	case G_SEEK_CUR :
-		if (0 == fseek (stdio->file, loffset, SEEK_CUR))
-			return FALSE;
-		break;
-	case G_SEEK_END :
-		if (0 == fseek (stdio->file, loffset, SEEK_END))
-			return FALSE;
 	}
 
+	if (0 == fseek (stdio->file, loffset, stdio_whence))
+		return FALSE;
+	
 	return TRUE;
 }
 
