@@ -185,7 +185,8 @@ gsf_input_textline_ascii_gets (GsfInputTextline *textline)
 
 		/* copy the remains into the buffer, grow it if necessary */
 		len = ptr - textline->remainder;
-		if ((count + len) > textline->buf_size) {
+		/* "+1", just in case len==0.  */
+		if (count + len + 1 > textline->buf_size) {
 			textline->buf_size += len;
 			textline->buf = g_realloc (textline->buf,
 				textline->buf_size + 1);
@@ -256,7 +257,7 @@ gsf_input_textline_utf8_gets (GsfInputTextline *textline)
 
 		ptr = textline->remainder;
 		end = ptr + textline->remainder_size;
-		for (; ptr < end ; ptr = g_utf8_next_char (ptr))
+		for (; ptr < end ; ptr = (guint8 *) g_utf8_next_char (ptr))
 			if (*ptr == '\n' || *ptr == '\r')
 				break;
 
