@@ -396,7 +396,7 @@ msole_prop_parse (GsfMSOleMetaDataSection *section,
 		GsfTimestamp ts;
 
 		ft /= 10000000; /* convert to seconds */
-		ft -= 11644473600; /* move to Jan 1 1970 */
+		ft -= 11644473600ULL; /* move to Jan 1 1970 */
 		ts.timet = (time_t)ft;
 		g_value_set_timestamp (res, &ts);
 		*data += 8;
@@ -444,7 +444,7 @@ msole_prop_parse (GsfMSOleMetaDataSection *section,
 		res = NULL;
 	};
 
-	d ( if (res != NULL) {
+	d ( if (res != NULL && G_IS_VALUE (res)) {
 		char *val = g_strdup_value_contents (res);
 		printf ("%s\n", val);
 		g_free (val);
@@ -640,11 +640,15 @@ gsf_msole_metadata_read (GsfInput *in, GError **err)
 			if (props[j].id == 1) {
 				GValue *v = msole_prop_read (in, sections+i, props, j);
 				if (v != NULL) {
-					int codepage = g_value_get_int (v);
-					sections[i].iconv_handle = gsf_msole_iconv_open_for_import (codepage);
-					if (codepage == 1200 || codepage == 1201)
-						sections[i].char_size = 2;
-					g_value_unset (v);
+					if (G_IS_VALUE (v)) {
+						if G_VALUE_HOLDS_INT (v) {
+							int codepage = g_value_get_int (v);
+							sections[i].iconv_handle = gsf_msole_iconv_open_for_import (codepage);
+							if (codepage == 1200 || codepage == 1201)
+								sections[i].char_size = 2;
+						}
+						g_value_unset (v);
+					}
 					g_free (v) ;
 				}
 			}
@@ -656,7 +660,8 @@ gsf_msole_metadata_read (GsfInput *in, GError **err)
 				GValue *v = msole_prop_read (in, sections+i, props, j);
 				if (v) {
 					/* FIXME: do something with it.  */
-					g_value_unset (v);
+					if (G_IS_VALUE (v))
+						g_value_unset (v);
 					g_free (v);
 				}
 			}
@@ -665,7 +670,8 @@ gsf_msole_metadata_read (GsfInput *in, GError **err)
 				GValue *v = msole_prop_read (in, sections+i, props, j);
 				if (v) {
 					/* FIXME: do something with it.  */
-					g_value_unset (v);
+					if (G_IS_VALUE (v))
+						g_value_unset (v);
 					g_free (v);
 				}
 			}
@@ -1022,6 +1028,8 @@ gsf_msole_lid_to_codepage (guint lid)
 			
 		case 0x0804:		/* Chinese (PRC) */
 			return 936;
+		default :
+			break;
 		}
 		break;
 	case 0x05:		/* Czech */
@@ -1056,6 +1064,8 @@ gsf_msole_lid_to_codepage (guint lid)
 			return 1361;
 		case 0x0412:		/* Korean */
 			return 949;
+		default :
+			break;
 		}
 		break;
 	case 0x13:		/* Dutch */
@@ -1080,6 +1090,8 @@ gsf_msole_lid_to_codepage (guint lid)
 			return 1251;
 		case 0x081a:		/* Serbian (Latin) */
 			return 1252;
+		default :
+			break;
 		}
 		break;
 	case 0x1b:		/* Slovak */
@@ -1118,6 +1130,8 @@ gsf_msole_lid_to_codepage (guint lid)
 		switch (lid) {
 		case 0x082c:		/* Azeri (Cyrillic) */
 			return 1251;
+		default :
+			break;
 		}
 		break;
 	case 0x2d:		/* Basque */
@@ -1140,6 +1154,8 @@ gsf_msole_lid_to_codepage (guint lid)
 		switch (lid) {
 		case 0x0843:		/* Uzbek (Cyrillic) */
 			return 1251;
+		default :
+			break;
 		}
 		break;
 	case 0x45:		/* Windows 2000: Bengali. This is Unicode only. */
