@@ -27,6 +27,7 @@
 #include <gsf/gsf-utils.h>
 
 #include <string.h>
+#include <stdio.h>
 
 #undef G_LOG_DOMAIN
 #define G_LOG_DOMAIN "libgsf:msole"
@@ -381,8 +382,8 @@ recalc_bat_bat :
 		}
 		i = 0;
 		if (num_bat > OLE_HEADER_METABAT_SIZE)
-			i = (num_bat - OLE_HEADER_METABAT_SIZE - 1)
-				/ OLE_DEFAULT_METABAT_SIZE;
+			i = 1 + ((num_bat - OLE_HEADER_METABAT_SIZE - 1)
+				 / OLE_DEFAULT_METABAT_SIZE);
 		if (num_xbat != i) {
 			num_xbat = i;
 			goto recalc_bat_bat;
@@ -393,8 +394,7 @@ recalc_bat_bat :
 		ole_pad_bat_unused (ole->sink);
 
 		if (num_xbat > 0) {
-			/* 1st xbat is immediately after bat */
-			xbat_pos = bat_start + num_bat;
+			xbat_pos = ole_cur_block (ole);
 			blocks = OLE_HEADER_METABAT_SIZE;
 		} else {
 			xbat_pos = BAT_MAGIC_END_OF_CHAIN;
@@ -458,7 +458,7 @@ recalc_bat_bat :
 		gsf_outfile_msole_seek (output, (gsf_off_t) 0, G_SEEK_END);
 		bb_pad_zero (ole->sink);
 		ole->blocks = ole_cur_block (ole) - ole->first_block;
-		return gsf_output_unwrap (ole->sink, output);
+		return gsf_output_unwrap (G_OBJECT (output), ole->sink);
 	}
 	return TRUE;
 }
@@ -481,7 +481,7 @@ gsf_outfile_msole_write (GsfOutput *output,
 				data, num_bytes);
 			return TRUE;
 		}
-		ok = gsf_output_wrap (ole->sink, output);
+		ok = gsf_output_wrap (G_OBJECT (output), ole->sink);
 		if (!ok)
 			return FALSE;
 
