@@ -34,8 +34,7 @@ typedef struct _GsfOutputMemory GsfOutputMemory;
 
 GType     gsf_output_memory_get_type (void);
 GsfOutput *gsf_output_memory_new      (void);
-void gsf_output_memory_get_bytes (GsfOutputMemory * mem,
-				  guint8 ** outbuffer, gsf_off_t * outlength);
+const guint8* gsf_output_memory_get_bytes (GsfOutputMemory * mem);
 
 G_END_DECLS
 
