@@ -32,6 +32,18 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#ifdef G_OS_WIN32
+
+#define S_IRGRP S_IRUSR
+#define S_IROTH S_IRUSR
+#define S_ISGID 0
+
+#define getuid() 0
+#define getgid() 0
+#define chown(filename, uid, gid) 0
+
+#endif /* G_OS_WIN32 */
+
 struct _GsfOutputStdio {
 	GsfOutput output;
 
@@ -58,6 +70,7 @@ typedef struct {
 static char *
 follow_symlinks (char const *filename, GError **error)
 {
+#ifdef HAVE_READLINK
 	gchar *followed_filename;
 	gint link_count;
 
@@ -114,22 +127,13 @@ follow_symlinks (char const *filename, GError **error)
 				      g_strerror (ELOOP));
 
 	return NULL;
+#else  /* !HAVE_READLINK */
+
+	return g_strdup (filename);
+
+#endif /* !HAVE_READLINK */
 }
 
-#if 0
-		switch (errno)
-		{
-			case ENOSPC:
-				msg = "There is not enough disk space to save the file.\n"
-					"Please free some disk space and try again.";
-				break;
-
-			case EFBIG:
-				msg = "The disk where you are trying to save the file has "
-					"a limitation on file sizes.  Please try saving "
-					"a smaller file or saving it to a disk that does not "
-					"have this limitation.";
-#endif
 /**
  * gsf_output_stdio_new :
  * @filename : in utf8.
@@ -304,7 +308,6 @@ gsf_output_stdio_finalize (GObject *obj)
 		parent_class->finalize (obj);
 }
 
-
 static gboolean
 gsf_output_stdio_seek (GsfOutput *output, gsf_off_t offset, GSeekType whence)
 {
@@ -340,20 +343,29 @@ gsf_output_stdio_write (GsfOutput *output,
 			guint8 const *buffer)
 {
 	GsfOutputStdio *stdio = GSF_OUTPUT_STDIO (output);
-	size_t res;
+	size_t written, remaining;
 
 	g_return_val_if_fail (stdio != NULL, FALSE);
 	g_return_val_if_fail (stdio->file != NULL, FALSE);
 
-	res = fwrite (buffer, 1, num_bytes, stdio->file);
-	return res == num_bytes;
+	remaining = num_bytes;
+
+	while (remaining > 0) {
+		written = fwrite (buffer + (num_bytes - remaining), 1, 
+				  remaining, stdio->file);
+		if ((written < remaining) && ferror (stdio->file) != 0) {
+			return gsf_output_set_error (output, errno, g_strerror (errno));
+		}
+		remaining -= written;
+	}
+	return TRUE;
 }
 
 static gboolean
-gsf_output_stdio_vprintf (GsfOutput *output, char const *format, va_list args)
+gsf_output_stdio_vprintf (GsfOutput *output, char const *fmt, va_list args)
 {
 	GsfOutputStdio *stdio = (GsfOutputStdio *)output;
-	int res = vfprintf (stdio->file, format, args);
+	int res = vfprintf (stdio->file, fmt, args);
 
 	return (res >= 0);
 }
