@@ -22,9 +22,13 @@
 #include <gsf-config.h>
 #include <gsf/gsf-output-impl.h>
 #include <gsf/gsf-impl-utils.h>
+#include <string.h>
 
 #define GET_CLASS(instance) G_TYPE_INSTANCE_GET_CLASS (instance, GSF_OUTPUT_TYPE, GsfOutputClass)
 
+static gboolean
+gsf_output_vprintf (GsfOutput *output, char const* format, va_list args);
+
 static void
 gsf_output_finalize (GObject *obj)
 {
@@ -38,10 +42,11 @@ gsf_output_finalize (GObject *obj)
 	if (!output->is_closed)
 		g_warning ("unrefing an unclosed stream");
 
-	if (output->name != NULL) {
-		g_free (output->name);
-		output->name = NULL;
-	}
+	g_free (output->name);
+	output->name = NULL;
+	g_free (output->printf_buf);
+	output->printf_buf = NULL;
+
 	if (output->container != NULL) {
 		g_object_unref (G_OBJECT (output->container));
 		output->container = NULL;
@@ -61,12 +66,17 @@ gsf_output_init (GObject *obj)
 	output->container	= NULL;
 	output->err		= NULL;
 	output->is_closed	= FALSE;
+	output->printf_buf	= NULL;
+	output->printf_buf_size = 0;
 }
 
 static void
 gsf_output_class_init (GObjectClass *gobject_class)
 {
+	GsfOutputClass  *output_class  = GSF_OUTPUT_CLASS (gobject_class);
+
 	gobject_class->finalize = gsf_output_finalize;
+	output_class->Vprintf   = gsf_output_vprintf;
 }
 
 GSF_CLASS_ABSTRACT (GsfOutput, gsf_output,
@@ -335,10 +345,9 @@ gsf_output_set_error (GsfOutput  *output,
 }
 
 static void
-cb_output_wrap_screwup (gpointer wrapee, GObject *wrapper)
+cb_output_unwrap (GsfOutput *wrapee, G_GNUC_UNUSED GObject *wrapper)
 {
-	g_warning ("%p died while still claiming ownership of %p",
-		   wrapper, wrapee);
+	wrapee->wrapped_by = NULL;
 }
 
 /**
@@ -349,7 +358,7 @@ cb_output_wrap_screwup (gpointer wrapee, GObject *wrapper)
  * Returns TRUE if the wrapping succeeded.
  **/
 gboolean
-gsf_output_wrap (GsfOutput *wrapper, GsfOutput *wrapee)
+gsf_output_wrap (GObject *wrapper, GsfOutput *wrapee)
 {
 	g_return_val_if_fail (wrapper != NULL, FALSE);
 	g_return_val_if_fail (wrapee != NULL, FALSE);
@@ -359,8 +368,8 @@ gsf_output_wrap (GsfOutput *wrapper, GsfOutput *wrapee)
 		return FALSE;
 	}
 
-	/* worry about someone dying with out unwrapping */
-	g_object_weak_ref (G_OBJECT (wrapper), cb_output_wrap_screwup, wrapee);
+	g_object_weak_ref (G_OBJECT (wrapper),
+		(GWeakNotify) cb_output_unwrap, wrapee);
 	wrapee->wrapped_by = wrapper;
 	return TRUE;
 }
@@ -373,13 +382,14 @@ gsf_output_wrap (GsfOutput *wrapper, GsfOutput *wrapee)
  * Returns TRUE if the wrapping succeeded.
  **/
 gboolean
-gsf_output_unwrap (GsfOutput *wrapper, GsfOutput *wrapee)
+gsf_output_unwrap (GObject *wrapper, GsfOutput *wrapee)
 {
 	g_return_val_if_fail (wrapee != NULL, FALSE);
 	g_return_val_if_fail (wrapee->wrapped_by == wrapper, FALSE);
 
 	wrapee->wrapped_by = NULL;
-	g_object_weak_unref (G_OBJECT (wrapper), cb_output_wrap_screwup, wrapee);
+	g_object_weak_unref (G_OBJECT (wrapper),
+		(GWeakNotify) cb_output_unwrap, wrapee);
 	return TRUE;
 }
 
@@ -391,3 +401,53 @@ gsf_output_error_id (void)
 		quark = g_quark_from_static_string ("gsf_output_error");
 	return quark;
 }
+
+static gboolean
+gsf_output_vprintf (GsfOutput *output, char const *fmt, va_list args)
+{
+	int reslen;
+
+	if (NULL == output->printf_buf) {
+		output->printf_buf_size = 128;
+		output->printf_buf = g_malloc (output->printf_buf_size);
+	}
+	reslen = g_vsnprintf (output->printf_buf, output->printf_buf_size, fmt, args);
+
+	/* handle C99 or older -1 case of vsnprintf */
+	if (reslen < 0 || reslen >= output->printf_buf_size) {
+		g_free (output->printf_buf);
+		output->printf_buf = g_strdup_vprintf (fmt, args);
+		reslen = output->printf_buf_size = strlen (output->printf_buf);
+	}
+
+	return gsf_output_write (output, reslen, output->printf_buf);
+}
+
+gboolean
+gsf_output_printf (GsfOutput *output, char const* format, ...)
+{
+	va_list args;
+	gboolean ret;
+
+	g_return_val_if_fail (output != NULL, FALSE);
+	g_return_val_if_fail (format != NULL, FALSE);
+	g_return_val_if_fail (strlen (format) > 0, FALSE);
+
+	va_start (args, format);
+	ret = GET_CLASS (output)->Vprintf (output, format, args);
+	va_end (args);
+
+	return ret;
+}
+
+/* Like fputs, this assumes that the line already ends with a newline */
+gboolean
+gsf_output_puts (GsfOutput *output, char const* line)
+{
+	size_t nbytes = 0;
+
+	g_return_val_if_fail (line != NULL, FALSE);
+
+	nbytes = strlen (line);
+	return gsf_output_write (output, nbytes, line);
+}
