@@ -62,7 +62,8 @@ gsf_timestamp_free (GsfTimestamp *stamp)
 }
 
 int
-gsf_timestamp_parse (char const *spec, GsfTimestamp *stamp)
+gsf_timestamp_parse (G_GNUC_UNUSED char const *spec,
+		     G_GNUC_UNUSED GsfTimestamp *stamp)
 {
 	return 0;
 }
@@ -70,8 +71,12 @@ gsf_timestamp_parse (char const *spec, GsfTimestamp *stamp)
 char *
 gsf_timestamp_as_string	(GsfTimestamp const *stamp)
 {
+	time_t t;
 	g_return_val_if_fail (stamp != NULL, g_strdup ("<invalid>"));
-	return g_strdup (ctime (&stamp->timet));
+
+	/* Use an honest time_t for ctime.  */
+	t = stamp->timet;
+	return g_strdup (ctime (&t));
 }
 
 guint
