@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gsf-msole.h: 
+ * gsf-zip-impl.h: 
  *
  * Copyright (C) 2002 Tambet Ingo (tambet@ximian.com)
  *
@@ -22,8 +22,6 @@
 #ifndef GSF_ZIP_IMPL_H
 #define GSF_ZIP_IMPL_H
 
-#include <gsf/gsf.h>
-
 G_BEGIN_DECLS
 
 #define ZIP_HEADER_SIZE 		30
@@ -75,6 +73,7 @@ G_BEGIN_DECLS
 #define ZIP_FILE_HEADER_NAME_SIZE       26
 #define ZIP_FILE_HEADER_EXTRAS_SIZE     28
 
+#define ZIP_NAME_SEPARATOR    '/'
 
 #define ZIP_BLOCK_SIZE 32768
 #define ZIP_BUF_SIZE 512
@@ -85,6 +84,44 @@ G_BEGIN_DECLS
 #define ZZIP_IS_COMPRLEVEL(p)  (((*(unsigned char*)p)>>1)&3)
 #define ZZIP_IS_STREAMED(p)    (((*(unsigned char*)p)>>3)&1)
 
+typedef enum {
+	ZIP_STORED =          0,
+	ZIP_SHRUNK =          1,
+	ZIP_REDUCEDx1 =       2,
+	ZIP_REDUCEDx2 =       3,
+	ZIP_REDUCEDx3 =       4,
+	ZIP_REDUCEDx4 =       5,
+	ZIP_IMPLODED  =       6,
+	ZIP_TOKENIZED =       7,
+	ZIP_DEFLATED =        8,
+	ZIP_DEFLATED_BETTER = 9,
+	ZIP_IMPLODED_BETTER = 10
+} ZipCompressionMethod;
+
+typedef struct {	
+	char                 *name;
+	ZipCompressionMethod  compr_method;
+	guint32               crc32;
+	size_t                csize;
+	size_t                usize;
+	off_t                 offset;
+	off_t                 data_offset;
+	guint32               dostime;
+} ZipDirent;
+
+typedef struct {
+	char *name;
+	gboolean is_directory;
+	ZipDirent *dirent;
+	GSList *children;
+} ZipVDir;
+
+ZipDirent* zip_dirent_new (void);
+void       zip_dirent_free (ZipDirent *dirent);
+
+ZipVDir* vdir_new (char const *name, gboolean is_directory, ZipDirent *dirent);
+void     vdir_free (ZipVDir *vdir, gboolean free_dirent);
+void     vdir_add_child (ZipVDir *vdir, ZipVDir *child);
 
 G_END_DECLS
 
