@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * libgsf.h: 
+ * gsf.h: 
  *
  * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
  *
@@ -23,7 +23,6 @@
 #define GSF_H
 
 #include <glib.h>
-#include <glib-object.h>
 
 G_BEGIN_DECLS
 
@@ -33,6 +32,7 @@ typedef struct _GsfInfile 	GsfInfile;
 typedef struct _GsfOutput	GsfOutput;
 typedef struct _GsfOutfile 	GsfOutfile;
 
+typedef struct _GsfDocProp	GsfDocProp;
 typedef struct _GsfDocMetaData	GsfDocMetaData;
 typedef struct _GsfTimestamp	GsfTimestamp;
 
@@ -41,6 +41,7 @@ typedef struct _GsfTimestamp	GsfTimestamp;
  * to on the platform
  */ 
 typedef gint64 gsf_off_t;
+#define GSF_OFF_T_FORMAT	G_GINT64_FORMAT
 
 G_END_DECLS
 
